%global _hardened_build 1
%global systemctl_bin /usr/bin/systemctl
%global selinuxtype targeted
%global with_selinux 0
%if 0%{?centos_ver} && 0%{?centos_ver} >= 8
%global with_selinux 1
%endif

%{!?_syprefix: %define _syprefix /opt/symas }
%{!?_etcfix: %define _etcfix %{_syprefix}/etc }
%{!?_sylibdir: %define _sylibdir %{_syprefix}/lib }
%{!?_varfix: %define _varfix /var/symas }

Name:		symas-openldap
Version:	2.6.5~rc1
Release:	2%{?dist}
Summary:	Symas's openldap build

License:	BSD
URL:		https://www.openldap.org
VCS: https://git.symas.net/symas-public/openldap.git

# These are the packages required to build OpenLDAP
BuildRequires:	symas-openssl-devel >= 3.0.0, symas-cyrus-sasl-devel >= 2.1.28-5
BuildRequires:	gcc, libtool-ltdl-devel, symas-heimdal-devel >= 7.8.0-3
BuildRequires:	libevent-devel, symas-libargon2-devel
BuildRequires:	cracklib-devel, systemd-devel

# SOURCE0 is unused, it's just for a theoretical reference
Source0: ftp://ftp.OpenLDAP.org/pub/OpenLDAP/openldap-release/openldap-%{version}.tgz
Source1: symas-openldap-servers.service
Source2: all_threads_full_bt.gdb
Source3: core_grab.gdb
Source4: core_wait.gdb
Source5: default_attach.gdb
Source6: connexitor.ldif
Source7: connexitor.schema
Source8: edupermission.ldif
Source9: edupermission.schema
Source10: eduperson.ldif
Source11: eduperson.schema
Source12: krb5-kdc.ldif
Source13: krb5-kdc.schema
Source14: qmail.ldif
Source15: qmail.schema
Source16: rfc2307bis.ldif
Source17: rfc2307bis.schema
Source18: samba.ldif
Source19: samba.schema
Source20: samba3.ldif
Source21: samba3.schema
Source22: exampledb.sh
Source23: exampledb-otp.sh
Source24: 50-soldap.sh
Source25: 50-soldap.csh
Source26: Symas-License.txt

# Do not try and automatically determine dependencies
AutoReqProv: No

# Patch0 and Patch1 are always required for 2.5
Patch0: Install-slapd-watcher.patch
Patch1: passwd.patch
# Any post-release specific patches should start here
Patch2: rc_fake.patch

%description
Symas's OpenLDAP 2.6 build

# Library package information
%package libs
Summary:	openldap Libaries
Requires:	symas-openssl-libs >= 3.0.0, symas-cyrus-sasl-libs >= 2.1.28-5
AutoReqProv:	no

%description libs
The symas-openldap-libs package contains the openldap libraries

# Devel package information
%package devel
Summary:	openldap Development
Requires:	symas-openldap-libs = %{version}-%{release}
AutoReqProv:	no

%description devel
The symas-openldap-devel package contains the linking libraries and include files

# Server package information
%package servers
Summary:	openldap server binaries
Requires:	symas-openldap-libs = %{version}-%{release}, symas-libargon2-libs, symas-heimdal-libs >= 7.8.0-3
%if 0%{?centos_ver} && 0%{?centos_ver} == 7
Requires:	cracklib >= 2.9.0
%else
Requires:	cracklib >= 2.9.6
%endif
Requires:	libevent
%if 0%{?suse_version}
Requires:	libltdl7
%else
Requires:	libtool-ltdl
%endif
%if 0%{?with_selinux}
# This ensures that the *-selinux package and all it’s dependencies are not pulled
# into containers and other systems that do not use SELinux
Requires:	(symas-openldap-servers-selinux if selinux-policy-%{selinuxtype})
%endif
Provides:	openldap-servers
Conflicts:	openldap-servers
AutoReqProv:	no

%description servers
The symas-openldap-servers package contains slapd and its modules

# Client package information
%package clients
Summary:	openldap client binaries
Requires: symas-openldap-libs = %{version}-%{release}
AutoReqProv:	no

%description clients
The symas-openldap-clients package contains client tools such as ldapsearch

# Moddev is a special package put together by Symas for making it possible
# to build 3rd party modules such as pw-bcrypt that require headers
# specific to the build process that are not included in the devel package
%package moddev
Summary: OpenLDAP module development pieces
Requires: symas-openldap-devel = %{version}-%{release}
AutoReqProv:	no

%description moddev
This package allows development of slapd overlays and modules using the
OpenlDAP libraries. It includes module specific headers and the libtool
utility required for compilation.

# Extract the source and apply patches
%prep
%setup -qn openldap-%{version}
# Patch0 and patch1 are mandatory
%patch0 -p1
%patch1 -p1
# Any additional post-release patches start here
%patch2 -p1

# Build the software
%build
%if 0%{?suse_version}
export LDFLAGS="-L%{_sylibdir} -Wl,-rpath,%{_sylibdir}"
%else
export LDFLAGS="%{__global_ldflags} -L%{_sylibdir} -Wl,-rpath,%{_sylibdir}"
%endif
export CFLAGS="%{optflags} -fPIC"
export CPPFLAGS=-I%{_syprefix}/include
./configure --prefix=%{_syprefix} \
    --with-cyrus-sasl \
    --with-tls=openssl \
    --libexecdir=%{_sylibdir} \
    --datadir=%{_varfix} \
    --sysconfdir=%{_etcfix} \
    --sharedstatedir=%{_etcfix} \
    --localstatedir=%{_varfix} \
    --enable-dynamic \
    --enable-slapd \
    --enable-modules \
    --enable-dynacl \
    --enable-balancer=mod \
    --enable-backends=mod \
		--disable-sql \
		--disable-perl \
		--disable-wt \
    --enable-overlays=mod \
		--disable-seqmod \
    --enable-argon2 \
    --enable-debug \
    --enable-spasswd \
    --enable-crypt \
    --enable-rlookups
make depend
make DEFINES="-DSLAP_SCHEMA_EXPOSE"
# Build the contrib modules
make -C contrib/slapd-modules/allowed prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/autogroup prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/datamorph prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/lastbind prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/noopsrch prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/passwd/pbkdf2 prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/passwd/sha2 prefix=%{_syprefix} libexecdir=%{_sylibdir} OPT=-fno-strict-aliasing
make -C contrib/slapd-modules/ppm prefix=%{_syprefix} libexecdir=%{_sylibdir} etcdir=%{_etcfix} OPT=-fPIC
make -C contrib/slapd-modules/rbac prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/smbk5pwd prefix=%{_syprefix} libexecdir=%{_sylibdir} \
 HEIMDAL_INC='-I%{_syprefix}/include/heimdal' HEIMDAL_LIB='-L%{_sylibdir} -lkrb5 -lkadm5srv' \
 SSL_INC='-I%{_syprefix}/include' SSL_LIB='-L%{_sylibdir} -lcrypto'
make -C contrib/slapd-modules/variant prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/authzid prefix=%{_syprefix} libexecdir=%{_sylibdir}
make -C contrib/slapd-modules/dsaschema prefix=%{_syprefix} libexecdir=%{_sylibdir}

# For the mdb_* binary commands
pushd libraries/liblmdb
export XCFLAGS="%{optflags}"
make prefix=%{_syprefix}
popd

# Install the software into the RPM buildroot
%install
make install DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/allowed install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/autogroup install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/datamorph install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/lastbind install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/noopsrch install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/passwd/pbkdf2 install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/passwd/sha2 install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS="" OPT=-fno-strict-aliasing
make -C contrib/slapd-modules/ppm install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS="" etcdir=%{_etcfix}
make -C contrib/slapd-modules/rbac install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/smbk5pwd install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/variant install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/authzid install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""
make -C contrib/slapd-modules/dsaschema install prefix=%{_syprefix} libexecdir=%{_sylibdir} DESTDIR=%{buildroot} STRIP_OPTS=""

# For the mdb_* binary commands
pushd libraries/liblmdb
make install prefix=%{_syprefix} DESTDIR=%{buildroot}
popd

# For slapd-watcher
pushd tests/progs
make install prefix=%{_syprefix} DESTDIR=%{buildroot}
popd

# Remove files we do not want distributed in the RPMs
rm -f %{buildroot}%{_syprefix}/include/lmdb.h
rm -f %{buildroot}%{_sylibdir}/liblmdb.a
rm -f %{buildroot}%{_sylibdir}/liblmdb.so
rm -f %{buildroot}%{_sylibdir}/openldap/allowed.a
rm -f %{buildroot}%{_sylibdir}/openldap/autogroup.a
rm -f %{buildroot}%{_sylibdir}/openldap/datamorph.a
rm -f %{buildroot}%{_sylibdir}/openldap/lastbind.a
rm -f %{buildroot}%{_sylibdir}/openldap/noopsrch.a
rm -f %{buildroot}%{_sylibdir}/openldap/ppm.a
rm -f %{buildroot}%{_sylibdir}/openldap/pw-pbkdf2.a
rm -f %{buildroot}%{_sylibdir}/openldap/pw-sha2.a
rm -f %{buildroot}%{_sylibdir}/openldap/rbac.a
rm -f %{buildroot}%{_sylibdir}/openldap/smbk5pwd.a
rm -f %{buildroot}%{_sylibdir}/openldap/variant.a
rm -f %{buildroot}%{_sylibdir}/openldap/authzid.a
rm -f %{buildroot}%{_sylibdir}/openldap/dsaschema.a
rm -f %{buildroot}%{_etcfix}/openldap/ppm.example
rm -f %{buildroot}%{_sylibdir}/*.la
rm -f %{buildroot}%{_unitdir}/slapd.service
mkdir -p %{buildroot}%{_varfix}/openldap-data
mkdir -p %{buildroot}%{_varfix}/run
chmod 0755 %{buildroot}%{_sylibdir}/lib*.so*
chmod 0644 %{buildroot}%{_sylibdir}/openldap/*.la

# Ensure these empty directories are a part of the resulting RPM buildroot
install -m 0700 -d %{buildroot}%{_varfix}/openldap-data
install -m 0755 -d %{buildroot}%{_varfix}/run

# install an init script for the servers
mkdir -p %{buildroot}%{_unitdir}
install -m 0644 %SOURCE1 %{buildroot}%{_unitdir}/
sed -i "s|/opt/symas|%{_syprefix}|g" %{buildroot}%{_unitdir}/symas-openldap-servers.service
pushd %{buildroot}%{_unitdir}
ln -s symas-openldap-servers.service slapd.service
popd

# Items specific to the moddev package
mkdir -p %{buildroot}%{_syprefix}/bin/moddev
install -m 0755 libtool %{buildroot}%{_syprefix}/bin/moddev/
install -m 0755 build/shtool %{buildroot}%{_syprefix}/bin/moddev/
mkdir -p %{buildroot}%{_syprefix}/include/moddev/ac
mkdir -p %{buildroot}%{_syprefix}/include/moddev/ucdata
mkdir -p %{buildroot}%{_syprefix}/include/moddev/back-monitor
install -m 0644 include/lber_pvt.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_avl.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_cdefs.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_config.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_defaults.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_features.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_int_thread.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_log.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_pvt.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_pvt_thread.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_pvt_uc.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_queue.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/lutil.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/lutil_lockf.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/portable.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/ldap_rq.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 include/rewrite.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 servers/slapd/proto-slap.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 servers/slapd/slap.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 servers/slapd/slap-config.h %{buildroot}%{_syprefix}/include/moddev/
install -m 0644 servers/slapd/back-monitor/back-monitor.h %{buildroot}%{_syprefix}/include/moddev/back-monitor/
install -m 0644 servers/slapd/back-monitor/proto-back-monitor.h %{buildroot}%{_syprefix}/include/moddev/back-monitor/
install -m 0644 include/ac/assert.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/bytes.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/fdset.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/localize.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/param.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/regex.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/signal.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/socket.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/stdlib.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/string.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/syslog.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/time.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/unistd.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/alloca.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/crypt.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/ctype.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/dirent.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/errno.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/stdarg.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/sysexits.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/termios.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 include/ac/wait.h %{buildroot}%{_syprefix}/include/moddev/ac/
install -m 0644 libraries/liblunicode/ucdata/ucdata.h %{buildroot}%{_syprefix}/include/moddev/ucdata/
sed -i "s|\.\./libraries/liblunicode/||" %{buildroot}%{_syprefix}/include/moddev/ldap_pvt_uc.h

# GDB helper scripts
mkdir -p %{buildroot}%{_sylibdir}/gdb
install -m 0644 %SOURCE2 %{buildroot}%{_sylibdir}/gdb/
install -m 0644 %SOURCE3 %{buildroot}%{_sylibdir}/gdb/
install -m 0644 %SOURCE4 %{buildroot}%{_sylibdir}/gdb/
install -m 0644 %SOURCE5 %{buildroot}%{_sylibdir}/gdb/

# Additional schema installation
install -m 0644 %SOURCE6 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE7 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE8 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE9 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE10 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE11 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE12 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE13 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE14 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE15 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE16 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE17 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE18 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE19 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE20 %{buildroot}%{_etcfix}/openldap/schema/
install -m 0644 %SOURCE21 %{buildroot}%{_etcfix}/openldap/schema/

# Install the example scripts
mkdir -p %{buildroot}%{_syprefix}/share/symas
install -m 0755 %SOURCE22 %{buildroot}%{_syprefix}/share/symas
install -m 0755 %SOURCE23 %{buildroot}%{_syprefix}/share/symas
sed -i "s|/opt/symas|%{_syprefix}|g" %{buildroot}%{_syprefix}/share/symas/exampledb.sh
sed -i "s|/opt/symas|%{_syprefix}|g" %{buildroot}%{_syprefix}/share/symas/exampledb-otp.sh

# Install the profile.d helper scripts that add the Symas locations
# to the user path
mkdir -p %{buildroot}/etc/profile.d
install -m 0644 %SOURCE24 %{buildroot}/etc/profile.d
install -m 0644 %SOURCE25 %{buildroot}/etc/profile.d
sed -i "s|/opt/symas|%{_syprefix}|g" %{buildroot}/etc/profile.d/50-soldap.sh
sed -i "s|/opt/symas|%{_syprefix}|g" %{buildroot}/etc/profile.d/50-soldap.csh

# Install the Symas open source license
mkdir -p %{buildroot}%{_syprefix}/share/doc/symas
install -m 0644 %SOURCE26 %{buildroot}%{_syprefix}/share/doc/symas

# Install OpenLDAP license and other documentation into the doc root
mkdir -p %{buildroot}%{_syprefix}/share/doc/openldap
install -m 0644 ANNOUNCEMENT %{buildroot}%{_syprefix}/share/doc/openldap
install -m 0644 CHANGES %{buildroot}%{_syprefix}/share/doc/openldap
install -m 0644 COPYRIGHT %{buildroot}%{_syprefix}/share/doc/openldap
install -m 0644 INSTALL %{buildroot}%{_syprefix}/share/doc/openldap
install -m 0644 LICENSE %{buildroot}%{_syprefix}/share/doc/openldap
install -m 0644 README %{buildroot}%{_syprefix}/share/doc/openldap

# Run the test suite
%check
make test

# Files for the libs package
%files libs
%defattr(-,root,root)
%{_etcfix}/openldap/ldap.conf.default
%{_sylibdir}/*.so.*
%{_syprefix}/share/man/man5/ldap.conf.5
%{_syprefix}/share/man/man5/ldif.5
%{_syprefix}/share/doc/openldap
%{_syprefix}/share/doc/symas
/etc/profile.d/50-soldap*

# Files for the devel package
%files devel
%defattr(-,root,root)
%{_syprefix}/include/*.h
%{_sylibdir}/*.a
%{_sylibdir}/*.so
%{_sylibdir}/pkgconfig/*.pc
%{_syprefix}/share/man/man3

# Files for the servers package
%files servers
%defattr(-,root,root)
%{_syprefix}/bin/mdb_*
%{_syprefix}/sbin
%{_etcfix}
%{_sylibdir}/slapd
%{_sylibdir}/openldap
%{_sylibdir}/gdb
%{_syprefix}/share/man/man1/mdb_*
%{_syprefix}/share/man/man5/slap*.5
%{_syprefix}/share/man/man5/lload*.5
%{_syprefix}/share/man/man8
%{_syprefix}/share/symas
%{_varfix}
%{_unitdir}/symas-openldap-servers.service
%{_unitdir}/slapd.service
%exclude %{_etcfix}/openldap/ldap.conf
%exclude %{_etcfix}/openldap/ldap.conf.default
%exclude %{_etcfix}/openldap/slapd.conf
%exclude %{_etcfix}/openldap/slapd.ldif
%exclude %{_syprefix}/share/man/man5/ldap.conf.5
%exclude %{_syprefix}/share/man/man5/ldif.5

# Files for the clients package
%files clients
%defattr(-,root,root)
%{_syprefix}/bin
%{_syprefix}/share/man/man1
%exclude %{_syprefix}/bin/mdb_*
%exclude %{_syprefix}/share/man/man1/mdb_*
%exclude %{_syprefix}/bin/moddev

# Files for the moddev package
%files moddev
%{_syprefix}/include/moddev
%{_syprefix}/bin/moddev

# post install commands
%post servers
%systemd_post symas-openldap-servers.service

# pre uninstall commands
%preun servers
%systemd_preun symas-openldap-servers.service

# post uninstall commands
%postun servers
%systemd_postun_with_restart symas-openldap-servers.service

%changelog
* Wed May 31 2023 Symas Support <support@symas.com> - 2.6.5~rc1-2
- OpenLDAP 2.6.5~rc1-2 with Openssl3 release candidate build
* Fri May 26 2023 Symas Support <support@symas.com> - 2.6.5~rc1-1
- OpenLDAP 2.6.5~rc1 release candidate build
* Wed Feb 08 2023 Symas Support <support@symas.com> - 2.6.4-1
- OpenLDAP 2.6.4 release
* Tue Jan 31 2023 Symas Support <support@symas.com> - 2.6.4~rc3-1
- OpenLDAP 2.6.4~rc3 release candidate build
* Thu Jan 19 2023 Symas Support <support@symas.com> - 2.6.4~rc2-1
- OpenLDAP 2.6.4~rc2 release candidate build
* Wed Oct 05 2022 Symas Support <support@symas.com> - 2.6.4~rc1-1
- OpenLDAP 2.6.4~rc1 release candidate build
- Added authzid contrib module
* Mon Jul 18 2022 Symas Support <support@symas.com> - 2.6.3-1
- OpenLDAP 2.6.3 release
* Wed Jul 13 2022 Symas Support <support@symas.com> - 2.6.3~rc2-1
- OpenLDAP 2.6.3~rc2 release candidate build
* Tue Jul 07 2022 Symas Support <support@symas.com> - 2.6.3~rc1-1
- OpenLDAP 2.6.3~rc1 release candidate build
* Tue May 10 2022 Symas Support <support@symas.com> - 2.6.2-1
- OpenLDAP 2.6.2 release
* Thu Mar 24 2022 15:28:22 Symas Support <support@symas.com> - 2.6.2-0rc1
- OpenLDAP 2.6.2-0rc1 release candidate
* Thu Jan 27 2022 Symas Support <support@symas.com> - 2.6.1-2
- ITS9787 patch fix
* Fri Jan 21 2022 Symas Support <support@symas.com> - 2.6.1-1
- OpenLDAP 2.6.1 release
* Wed Jan 05 2022 Symas Support <support@symas.com> - 2.6.0-6
- Enable dynacl support
- Update moddev package with additional headers necessary for dynacl builds
* Mon Dec 13 2021 Symas Support <support@symas.com> - 2.6.0-5
- Package slapo-allowed contrib module
- ITS9756 patch fix
* Wed Dec 01 2021 Symas Support <support@symas.com> - 2.6.0-4
- ITS9747 patch fix
- ITS9752 patch fix
- ITS9753 patch fix
- ITS9725 patch fix
* Tue Nov 16 2021 Symas Support <support@symas.com> - 2.6.0-3
- ITS9745 patch fix
- Package ANNOUNCEMENT, CHANGES, COPYRIGHT, INSTALL, LICENSE, and README files
* Fri Oct 29 2021 Symas Support <support@symas.com> - 2.6.0-2
- ITS9730 patch fix
* Tue Oct 26 2021 Symas Support <support@symas.com> - 2.6.0-1
- OpenLDAP 2.6.0 release
- ITS9715 patch fix
